@@ -8,7 +8,7 @@ use HTML::TableExtract;
 use experimental qw(switch);
 
 # ABSTRACT: Archive Devel::Cover reports
-our $VERSION = '1.002';
+our $VERSION = '1.004'; # VERSION
 
 with 'MooseX::Getopt';
 
@@ -299,7 +299,7 @@ App::ArchiveDevelCover - Archive Devel::Cover reports
 
 =head1 VERSION
 
-version 1.003
+version 1.004
 
 =head1 SYNOPSIS
 
@@ -307,7 +307,7 @@ Backend for the C<archive_devel_cover.pl> command. See L<archive_devel_cover.pl>
 
 =head1 AUTHOR
 
-Thomas Klausner <domm@cpan.org>
+Thomas Klausner <domm@plix.at>
 
 =head1 COPYRIGHT AND LICENSE
 
